pub struct CameraObject {
pub params: ParamMap,
pub colors: HashMap<String, Color>,
pub textures: HashMap<String, Texture>,
}Expand description
A CameraObject structure contains data for a camera object.
Fields
params: ParamMapA map of parameters associated with this camera.
The OpenGEX specification defined three parameters: “fov”, “near” and “far”. Any other parameters are application-specific.
colors: HashMap<String, Color>A map of colors associated with this camera. The OpenGEX specification does not define any kinds of colors.
textures: HashMap<String, Texture>A map of textures associated with this camera. The OpenGEX specification does not define any kinds of textures.